@@ -1,3 +1,15 @@
+#!/usr/bin/env python
+# coding=utf-8
+
+SYMBOL_TYPE_SPOT = 'SPOT'
+
+ORDER_STATUS_NEW = 'NEW'
+ORDER_STATUS_PARTIALLY_FILLED = 'PARTIALLY_FILLED'
+ORDER_STATUS_FILLED = 'FILLED'
+ORDER_STATUS_CANCELED = 'CANCELED'
+ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'
+ORDER_STATUS_REJECTED = 'REJECTED'
+ORDER_STATUS_EXPIRED = 'EXPIRED'
 
 KLINE_INTERVAL_1MINUTE = '1m'
 KLINE_INTERVAL_2MINUTE = '3m'
